@@ -2,9 +2,10 @@ package DBIx::Async;
 # ABSTRACT: database support for IO::Async via DBI
 use strict;
 use warnings;
+
 use parent qw(IO::Async::Notifier);
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 =head1 NAME
 
@@ -12,7 +13,7 @@ DBIx::Async - use L<DBI> with L<IO::Async>
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -25,7 +26,7 @@ version 0.002
  my $loop = IO::Async::Loop->new;
  say 'Connecting to db';
  $loop->add(my $dbh = DBIx::Async->connect(
-   'dbi:SQLite:dbname=test.sqlite3',
+   'dbi:SQLite:dbname=:memory:',
    '',
    '', {
      AutoCommit => 1,
@@ -51,9 +52,7 @@ version 0.002
    );
  })->on_done(sub {
    say "Query complete";
-   $loop->stop;
- })->on_fail(sub { warn "Failure: @_\n" });
- $loop->run;
+ })->on_fail(sub { warn "Failure: @_\n" })->get;
 
 =head1 DESCRIPTION
 
@@ -84,11 +83,21 @@ use IO::Async::Channel;
 use IO::Async::Routine;
 use Future;
 use Module::Load qw();
-use Try::Tiny;
+
+use Variable::Disposition qw(retain_future);
 
 use DBIx::Async::Handle;
 
-use constant DEBUG => 0;
+# temporary pending next release of curry
+our $_curry_weak = sub {
+	my ($invocant, $code) = splice @_, 0, 2;
+	Scalar::Util::weaken($invocant) if Scalar::Util::blessed($invocant);
+	my @args = @_;
+	sub {
+		return unless $invocant;
+		$invocant->$code(@args => @_)
+	}
+};
 
 =head2 connect
 
@@ -197,10 +206,10 @@ Returns a L<Future> which will resolve when this query completes.
 sub do : method {
 	my ($self, $sql, $options, @params) = @_;
 	$self->queue({
-		op => 'do',
-		sql => $sql,
+		op      => 'do',
+		sql     => $sql,
 		options => $options,
-		params => \@params,
+		params  => \@params,
 	});
 }
 
@@ -296,7 +305,7 @@ sub prepare {
 	my $self = shift;
 	my $sql = shift;
 	DBIx::Async::Handle->new(
-		dbh => $self,
+		dbh     => $self,
 		prepare => $self->queue({ op => 'prepare', sql => $sql }),
 	);
 }
@@ -319,27 +328,36 @@ sub queue {
 	my $self = shift;
 	my ($req, $code) = @_;
 	my $f = $self->loop->new_future;
-	if(DEBUG) {
-		require Data::Dumper;
-		warn "Sending req " . Data::Dumper::Dumper($req);
-	}
+	$self->debug_printf("Sending request [%s]", join ',', map { $_ . '=' . ($req->{$_} // '<undef>') } sort keys %$req);
+
 	$self->sth_ch->send($req);
 	$self->ret_ch->recv(
 		on_recv => sub {
-			my ( $ch, $rslt ) = @_;
+			my ($ch, $rslt) = @_;
 			if($rslt->{status} eq 'ok') {
 				$f->done($rslt);
 			} else {
-				$f->fail($rslt->{message});
+				$f->fail($rslt->{message} // 'unknown exception');
 			}
 		}
 	);
-	$f
+	retain_future $f;
 }
 
 =head2 worker_class_from_dsn
 
-Returns $self.
+Attempts to locate a suitable worker subclass, given a DSN.
+
+For example:
+
+ $dbh->worker_class_from_dsn('dbi:SQLite:memory')
+
+should return 'DBIx::Async::Worker::SQLite'.
+
+Note that this method will load the class if it is not already
+present.
+
+Returns the class as a string.
 
 =cut
 
@@ -348,16 +366,20 @@ sub worker_class_from_dsn {
 	my $dsn = shift;
 	my ($dbd) = $dsn =~ /^dbi:([^:]+)(?::|$)/;
 	die "Invalid DBD class: $dbd" unless $dbd =~ /^[a-zA-Z0-9]+$/;
+
 	my $loaded;
 	my $class;
 	for my $subclass ($dbd, 'Default') {
 		last if $loaded;
 		$class = 'DBIx::Async::Worker::' . $subclass;
-		try {
+		eval {
 			Module::Load::load($class);
 			$loaded = 1
-		} catch {
-			warn "class load: $_\n" if DEBUG;
+		} or do {
+			# TODO we need proper error handling here,
+			# but some DSNs won't have a related worker
+			# class, default to something perhaps?
+			warn "Failed to load: $@"
 		};
 	}
 	die "Could not find suitable class for $dbd" unless $loaded;
@@ -398,24 +420,23 @@ sub _add_to_loop {
 		channels_in  => [ $self->{sth_ch} ],
 		channels_out => [ $self->{ret_ch} ],
 		code => sub { $worker->run },
-		on_finish => sub {
-			print "The routine aborted early - $_[-1]\n";
-			$self->loop->stop;
-		},
+		on_finish => $self->$_curry_weak(sub {
+			my $self = shift;
+			$self->debug_printf("The routine aborted early with [%s]", $_[-1]);
+		}),
 	);
-	$loop->add($routine);
+	$self->add_child($routine);
 }
 
 =head2 _remove_from_loop
 
-Doesn't do anything.
+Doesn't do anything yet.
 
 =cut
 
 sub _remove_from_loop {
 	my $self = shift;
 	my ($loop) = @_;
-	warn "Removed from loop\n" if DEBUG;
 }
 
 1;
@@ -447,8 +468,8 @@ natively, might lead to some performance improvements.
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2012-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2012-2015. Licensed under the same terms as Perl itself.
