@@ -1,7 +1,5 @@
 package DBIx::Async::Worker;
-{
-  $DBIx::Async::Worker::VERSION = '0.002';
-}
+$DBIx::Async::Worker::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -11,7 +9,7 @@ DBIx::Async::Worker - background process for L<DBIx::Async>
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
@@ -21,7 +19,6 @@ for specific DBD driver support though.
 =cut
 
 use DBI;
-use Try::Tiny;
 
 my %VALID_METHODS;
 BEGIN {
@@ -49,28 +46,27 @@ sub new { my $class = shift; bless { @_ }, $class }
 
 =head2 ret_ch
 
-Returns $self.
-
 =cut
 
 sub ret_ch { shift->{ret_ch} }
 
 =head2 sth_ch
 
-Returns $self.
-
 =cut
 
 sub sth_ch { shift->{sth_ch} }
 
 =head2 parent
 
-Returns $self.
 
 =cut
 
 sub parent { shift->{parent} }
 
+=head2 connect
+
+=cut
+
 sub connect {
 	my $self = shift;
 	$self->{dbh} = DBI->connect(
@@ -82,6 +78,10 @@ sub connect {
 	$self;
 }
 
+=head2 do
+
+=cut
+
 sub do : method {
 	my $self = shift;
 	my $op = shift;
@@ -93,6 +93,10 @@ sub do : method {
 	return { status => 'ok' };
 }
 
+=head2 begin_work
+
+=cut
+
 sub begin_work {
 	my $self = shift;
 	my $op = shift;
@@ -100,6 +104,10 @@ sub begin_work {
 	return { status => 'ok' };
 }
 
+=head2 commit
+
+=cut
+
 sub commit {
 	my $self = shift;
 	my $op = shift;
@@ -107,6 +115,10 @@ sub commit {
 	return { status => 'ok' };
 }
 
+=head2 savepoint
+
+=cut
+
 sub savepoint {
 	my $self = shift;
 	my $op = shift;
@@ -114,6 +126,10 @@ sub savepoint {
 	return { status => 'ok' };
 }
 
+=head2 release
+
+=cut
+
 sub release {
 	my $self = shift;
 	my $op = shift;
@@ -121,6 +137,10 @@ sub release {
 	return { status => 'ok' };
 }
 
+=head2 rollback
+
+=cut
+
 sub rollback {
 	my $self = shift;
 	my $op = shift;
@@ -128,6 +148,10 @@ sub rollback {
 	return { status => 'ok' };
 }
 
+=head2 prepare
+
+=cut
+
 sub prepare {
 	my $self = shift;
 	my $op = shift;
@@ -136,6 +160,10 @@ sub prepare {
 	return { status => 'ok', id => "$sth" };
 }
 
+=head2 finish
+
+=cut
+
 sub finish {
 	my $self = shift;
 	my $op = shift;
@@ -147,6 +175,10 @@ sub finish {
 	return { status => 'ok', id => "$sth" };
 }
 
+=head2 execute
+
+=cut
+
 sub execute {
 	my $self = shift;
 	my $op = shift;
@@ -158,6 +190,10 @@ sub execute {
 	return { status => 'ok', id => "$sth" };
 }
 
+=head2 fetchrow_hashref
+
+=cut
+
 sub fetchrow_hashref {
 	my $self = shift;
 	my $op = shift;
@@ -169,24 +205,37 @@ sub fetchrow_hashref {
 	return { status => 'ok', id => "$sth", data => $data };
 }
 
+=head2 dbh
+
+=cut
+
 sub dbh { shift->{dbh} }
 
+=head2 run
+
+=cut
+
 sub run {
 	my $self = shift;
-	try {
+	eval {
 		$self->connect;
 		$self->setup;
-	} catch {
-		warn "Failure: $_";
+		1
+	} or do {
+		warn "Failure: $@";
 	};
 	while(my $data = $self->sth_ch->recv) {
-		try {
+		eval {
 			my $method = $data->{op};
 			my $code = $self->can($method) or die 'unknown operation';
 			$self->ret_ch->send($code->($self, $data));
-		} catch {
+			1
+		} or do {
 			# warn "err: $_\n";
-			$self->ret_ch->send({ status => 'fail', message => $_ });
+			$self->ret_ch->send({
+				status => 'fail',
+				message => $@
+			});
 		};
 	}
 }
@@ -197,8 +246,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2012-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2012-2015. Licensed under the same terms as Perl itself.
