@@ -1,9 +1,8 @@
 package DBIx::Async::Worker::SQLite;
-{
-  $DBIx::Async::Worker::SQLite::VERSION = '0.002';
-}
+$DBIx::Async::Worker::SQLite::VERSION = '0.003';
 use strict;
 use warnings;
+
 use parent qw(DBIx::Async::Worker);
 
 use constant DEBUG => 0;
@@ -42,9 +41,9 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2012-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2012-2015. Licensed under the same terms as Perl itself.
 
